@@ -5,7 +5,7 @@ use lib 'lib', '../lib' ;
 use Term::Shell::MultiCmd;
 my @command_tree =
   ( 'confess' =>
-    { help => 'Just testing multi options
+    { help => 'Test multiple options
 try:
 confess -name="Some String" -flag 2 -flag 3 -flag 4 -force
 ',
@@ -21,6 +21,13 @@ sub confession {
     print Dumper \%p ;
 }
 
+print <<"Hi" ;
+This one is testing multiple options in command line.
+try:
+ confess -name="Some String" -flag 2 -flag 3 -flag 4 -force
+
+Hi
+
 Term::Shell::MultiCmd
   -> new()
   -> populate( @command_tree )
