@@ -11,7 +11,7 @@ Term::Shell::MultiCmd -  Nested Commands Tree in Shell Interface
 
 =cut
 
-our $VERSION = '2.03';
+our $VERSION = '3.01';
 
 =head1 SYNOPSIS
 
@@ -167,6 +167,7 @@ sub _travela($@) {              # explicit array
 
 sub _travel($$) {
     my ($o, $c) = &_check_pager ; # clear $c pager sign, let cmd know about it.
+    ($o, $c) = &_check_sh_pipe if $o->{enable_sh_pipe} and not $o->{piper};
     $c = _check_silent_aliases($o, $c);
     _travela( $o, _split $o, $c )
 }
@@ -338,6 +339,26 @@ Function ref only, call it when user hits 'Return' with no command or args (not
                                        ) ;
 
 
+=item * -query_cmd
+
+If exeuting a node, and node contains the query cmd, it would be executed instead of the help command (on the node)
+Default: 'query'
+For exmaple, with this feature, if "my cmd query" exists, it would also be exeuted at "my cmd'
+
+   my $cli = new Term::Shell::MultiCmd ( -query_cmd => 'query',
+                                       ) ;
+=item * -enable_sh_pipe
+
+If true, allow redirect output to a shell command by the suffix ' | <chell cmd>'. Example:
+Shell> my multy path cmd | grep -w 42
+Default is value is 1, To disable, set it to false (0 or '' or undef)
+
+   my $cli = new Term::Shell::MultiCmd ( -enable_sh_pipe => '',
+                                       ) ;
+
+Note: If both pager and this pipe are used, the pipe will be ingored and the command will get whole line
+as argument.
+
 =back
 
 =cut
@@ -367,10 +388,12 @@ sub _new_readline($) {
 
 sub new {
     my $class = shift ;
-    my %p = _params 'help_cmd=help quit_cmd=quit root_cmd= prompt=shell>
-                     history_file= history_size=100 history_more= pager= pager_re=^\|
-                     record_cmd= empty_cmd=
-                     ', @_ ;
+    my $params = 'help_cmd=help quit_cmd=quit root_cmd= prompt=shell>
+                  history_file= history_size=100 history_more= pager= pager_re=^\|
+                  query_cmd=query enable_sh_pipe=1
+                  record_cmd= empty_cmd=
+                  ';
+    my %p = _params $params, @_ ;
 
     # structure rules:
     # hash ref is a path, keys are items (commands or paths) special item $dlm is one liner help
@@ -378,9 +401,7 @@ sub new {
     #  where: first help line is the one liner, default completion might be good enough
 
     my $o = bless { cmds => { },
-                    map {($_, $p{$_})} qw/prompt pager history_file history_size history_more
-                                          help_cmd quit_cmd root_cmd pager pager_re record_cmd empty_cmd
-                                         /
+                    map {($_, $p{$_})} map { /^(\w+)/ } split ' ', $params
                   }, ref ( $class ) || $class ;
 
     $o -> {delimiter  } = ' '   ; # now, programmers can manipulate the next two values after creating the object,
@@ -418,12 +439,12 @@ sub _root_cmds_set($;$$) {
 Options:
 $PATH -t --tree      : Show commands tree
 $PATH -r --recursive : Show full help instead of title, recursively'
-                   ) ;
+                   ) if $o->{help_cmd};
 
     $o -> add_exec ( path => $o->{quit_cmd},
                      exec => \&_quit_command,
                      help => 'Exit this shell',
-                   ) ;
+                   ) if $o->{quit_cmd};
 
     $o -> add_exec ( path => $o->{root_cmd},
                      exec => \&_root_command,
@@ -438,7 +459,7 @@ $PATH a path to command -with options
                          : execute command from real root, options would be forwarded
                          : to the command.
 '
-                   ) ;
+                   ) if $o->{root_cmd};
     ($o->{root}, $o->{cmds}, $o->{root_path}) = ($o->{cmds}, $root, $path) if $root ;
 }
 
@@ -865,13 +886,30 @@ sub _root_command {
     }
 }
 
+sub _check_sh_pipe {
+    my ($o, $c) = @_ ;
+    my $r = qr/(\|.*)$/;
+    if ($c =~ s/$r//) {
+        my $cmd = $1;
+        $o->{piper} = 'c';
+        $o->{shcmd} = sub { use FileHandle ; new FileHandle $cmd };
+    }
+    ($o, $c)
+}
+
 sub _check_pager {
     my ($o, $c) = @_ ;
     my $p = $o->{pager} or return (@_, $o->{piper}=undef); # just in case programmer delete {pager} during run
-    ref $p or $o->{pager} = sub { use FileHandle ; new FileHandle "| $p" };
-    my $r = $o->{pager_re} ;
-    !$r or ref $r or $r = do{ my $d = "$r($o->{delimiterRE})*" ; $o->{pager_re} = qr/$d/};
-    $o->{piper} = !$r || $c =~ s/$r// ;
+    my $r = $o->{pager_re};
+    if ($r and not ref $r) {    # once
+        my $d = "$r($o->{delimiterRE})*" ;
+        $r =  $o->{pager_re} = qr/$d/;
+    }
+    if (!$r or
+        $r && $c =~ s/$r//) {
+        $o->{piper} = 'p';
+        $o->{pager} = sub { use FileHandle ; new FileHandle "| $p" } unless ref $o->{pager};
+    }
     ($o, $c)
 }
 
@@ -879,7 +917,7 @@ sub _check_silent_aliases {
     my ($o, $cmd) = @_ ;
     return  $cmd unless $cmd;
     my $r = $o->{root} || $o->{cmds};
-    my ($c, @a) = _split $o, $cmd;
+    my ($c, @a) = _split $o, $cmd || '';
 
     return _join $o, $o->{root_cmd}, (@a ? (-set => @a ) : ('-clear'))
       if ( $c eq 'cd' and
@@ -907,10 +945,13 @@ sub cmd {
     my ($o, $clt) = @_;
     $o->{record_cmd}->($clt) if 'CODE' eq ref $o->{record_cmd};
 
-    my ($cmd, $path, @args, $fh) = _travel $o, $clt or return ;
+    my ($cmd, $path, @args) = _travel $o, $clt or return ;
     local %SIG ;
 
-    if ($o->{piper} and $fh = $o->{pager}->()) {
+    my $fh;
+    $fh = $o->{pager}->() if 'p' eq ($o->{piper}||'');
+    $fh = $o->{shcmd}->() if 'c' eq ($o->{piper}||'') and not $fh;
+    if ($fh) {
         $o->{stdout} = select ;
         select $fh ;
         $SIG{PIPE} = sub {} ;
@@ -920,6 +961,7 @@ sub cmd {
 
     if ($fh) {
         select $o->{stdout} ;
+        $o->{piper} = $o->{shcmd} = undef;
     }
     $res
 }
@@ -929,6 +971,7 @@ sub _cmd {
     return print $cmd unless ref $cmd ;
     return $o->{empty_cmd}->() if $o->{empty_cmd} and $cmd eq ($o -> {root} || $o->{cmds}) and 0 == length join '', @args;
     return _say "No such command or prefix: " . _join $o, @args if $cmd eq $o->{cmds} ;
+    $cmd = $cmd->{$o->{query_cmd}} if 'HASH' eq ref $cmd and length($o->{query_cmd}) and exists $cmd->{$o->{query_cmd}};
     return _help_message($o, -node => $cmd, -path => $path) unless 'ARRAY' eq ref $cmd ; # help message
     my %p = _options $cmd->[3] || '', @args ;
     return print $p{_ERR_} if $p{_ERR_} ;
